@@ -169,6 +169,16 @@ bootstrap_model.merMod <- function(model,
     params <- insight::get_parameters(model, verbose = FALSE)
     n_params <- insight::n_parameters(model)
 
+    # for glmmTMB, remove dispersion paramters, if any
+    if (inherits(model, "glmmTMB") && "Component" %in% names(params) && "dispersion" %in% params$Component) {
+      # find number of dispersion parameters
+      n_disp <- sum(params$Component == "dispersion")
+      # remove dispersion parameters
+      params <- params[params$Component != "dispersion", ]
+      # make sure number of parameters is updated
+      n_params <- n_params - n_disp
+    }
+
     if (nrow(params) != n_params) {
       params <- stats::setNames(rep.int(NA, n_params), params$Parameter)
     } else {
@@ -212,70 +222,3 @@ bootstrap_model.merMod <- function(model,
 
 #' @export
 bootstrap_model.glmmTMB <- bootstrap_model.merMod
-
-
-
-
-
-
-# bootstrap_model.htest <- function(model, n = 1000, verbose = FALSE, ...) {
-#   data <- insight::get_data(model)
-#
-#   boot_function <- function(model, data, indices) {
-#     d <- data[indices, ] # allows boot to select sample
-#
-#     if (verbose) {
-#       fit <- suppressMessages(update(model, data = d))
-#     } else {
-#       fit <- update(model, data = d)
-#     }
-#
-#     return(model$estimate)
-#   }
-#
-#   results <- boot::boot(data = data, statistic = boot_function, R = n, model = model)
-#
-#   return(results)
-# }
-
-
-
-
-
-
-
-
-
-
-
-#' @export
-as.data.frame.lm <- function(x,
-                             row.names = NULL,
-                             optional = FALSE,
-                             iterations = 1000,
-                             verbose = FALSE,
-                             ...) {
-  bootstrap_model(x, iterations = iterations, verbose = verbose, ...)
-}
-
-
-#' @export
-as.data.frame.merMod <- function(x,
-                                 row.names = NULL,
-                                 optional = FALSE,
-                                 iterations = 1000,
-                                 verbose = FALSE,
-                                 ...) {
-  bootstrap_model(x, iterations = iterations, verbose = verbose, ...)
-}
-
-
-#' @export
-as.data.frame.glmmTMB <- function(x,
-                                  row.names = NULL,
-                                  optional = FALSE,
-                                  iterations = 1000,
-                                  verbose = FALSE,
-                                  ...) {
-  bootstrap_model(x, iterations = iterations, verbose = verbose, ...)
-}
