@@ -93,6 +93,8 @@
 .extract_anova_manova <- function(model) {
   parameters <- as.data.frame(summary(model)$stats)
   parameters$Parameter <- insight::trim_ws(row.names(parameters))
+  parameters$df_num <- parameters[["num Df"]]
+  parameters$df_error <- parameters[["den Df"]]
   parameters[["den Df"]] <- NULL
   parameters[["num Df"]] <- NULL
   parameters
@@ -184,7 +186,7 @@
   if (!is.null(m_attr$value) && isTRUE(startsWith(m_attr$heading[[1]], "Linear hypothesis"))) {
     # Drop unrestricted model (not interesting in linear hypothesis tests)
     # Use formula to subset if available (e.g. with car::linearHypothesis)
-    if (length(grep("Model", m_attr$heading, fixed = TRUE)) != 0) {
+    if (any(grepl("Model", m_attr$heading, fixed = TRUE))) {
       idx <- sub(".*: ", "", strsplit(
         grep("Model", m_attr$heading, fixed = TRUE, value = TRUE),
         "\n",
