@@ -1,3 +1,9 @@
+# small wrapper around this commonly used try-catch
+.safe <- function(code, on_error = NULL) {
+  tryCatch(code, error = function(e) on_error)
+}
+
+
 #' help-functions
 #' @keywords internal
 .data_frame <- function(...) {
@@ -57,7 +63,7 @@
 # Find log-terms inside model formula, and return "clean" term names
 .log_terms <- function(model) {
   x <- insight::find_terms(model, flatten = TRUE)
-  gsub("^log\\((.*)\\)", "\\1", x[grepl("^log\\((.*)\\)", x)])
+  gsub("^log\\((.*)\\)", "\\1", grep("^log\\((.*)\\)", x, value = TRUE))
 }
 
 
@@ -80,10 +86,10 @@
   obj_name <- attr(x, attribute_name, exact = TRUE)
   model <- NULL
   if (!is.null(obj_name)) {
-    model <- tryCatch(get(obj_name, envir = parent.frame()), error = function(e) NULL)
+    model <- .safe(get(obj_name, envir = parent.frame()))
     # prevent self reference
     if (is.null(model) || inherits(model, "parameters_model")) {
-      model <- tryCatch(get(obj_name, envir = globalenv()), error = function(e) NULL)
+      model <- .safe(get(obj_name, envir = globalenv()))
     }
   }
   model
